==> HostCMS.Free_6.7.tar.gz: modules/xsl/i18n/ru.php <==
<?php
/**
 * XSL.
 *
 * @package HostCMS
 * @subpackage Xsl
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'XSL-шаблоны',
	'menu' => 'XSL-шаблоны',
	'tab2' => 'Комментарий',
	'tab_dtd' => '%s.dtd',
	'edit_success' => 'Информация об XSL-шаблоне изменена.',
	'markDeleted_success' => 'XSL-шаблон успешно удален.',
	'apply_success' => 'Информация изменена.',
	'copy_success' => 'Шаблон успешно скопирован!',
	'add_title' => 'Добавление информации об XSL-шаблоне',
	'edit_title' => 'Редактирование информации об XSL-шаблоне',
	'id' => 'Идентификатор',
	'xsl_dir_id' => '<acronym title="Выберите раздел XSL-шаблона">Раздел XSL-шаблона</acronym>',
	'name' => '<acronym title="Название XSL-шаблона">Название XSL-шаблона</acronym>',
	'sorting' => '<acronym title="Порядковый номер XSL-шаблона в списке шаблонов раздела">Порядковый номер XSL-шаблона</acronym>',
	'value' => '<acronym title="Код XSL-шаблона">Код XSL-шаблона</acronym>',
	'dtd' => '<acronym title="Код DTD для языка">Код DTD для языка "%s"</acronym>',
	'format' => '<acronym title="Форматирование XSL-документа">Форматировать XSL-шаблон</acronym>',
	'description' => '<acronym title="Дополнительная информация об XSL-шаблоне в свободной форме">Комментарий к XSL-шаблону</acronym>',
	'xsl_already_exists' => 'XSL-шаблон с таким названием уже существует! Введите уникальное имя XSL-шаблона',
	'main_menu' => 'XSL-шаблон',
	'panel_edit_xsl' => 'Редактировать XSL-шаблон "%s"',
	'panel_edit_xml' => 'XML для XSL-шаблона "%s"',
	'panel_xsl_time' => '%.3f с',
	'panel_xsl_size' => '%s байт',
	'XSL_dir_title' => 'Разделы XSL',
	'XSL_root_dir' => 'XSL-шаблоны',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
);

==> HostCMS.Free_7.0.tar.gz: modules/xsl/i18n/ru.php <==
<?php
/**
 * XSL.
 *
 * @package HostCMS
 * @subpackage Xsl
 * @version 7.x
 * @author Hostmake LLC
 * @copyright © 2005-2022 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'XSL-шаблоны',
	'menu' => 'XSL-шаблоны',
	'tab2' => 'Комментарий',
	'tab_dtd' => '%s.dtd',
	'edit_success' => 'Информация об XSL-шаблоне изменена.',
	'markDeleted_success' => 'XSL-шаблон успешно удален.',
	'apply_success' => 'Информация изменена.',
	'copy_success' => 'Шаблон успешно скопирован!',
	'add_title' => 'Добавление информации об XSL-шаблоне',
	'edit_title' => 'Редактирование информации об XSL-шаблоне "%s"',
	'id' => 'Идентификатор',
	'xsl_dir_id' => 'Раздел XSL-шаблона',
	'name' => 'Название XSL-шаблона',
	'sorting' => 'Порядковый номер XSL-шаблона',
	'value' => 'Код XSL-шаблона',
	'dtd' => 'Код DTD для языка "%s"',
	'format' => 'Форматировать XSL-шаблон',
	'description' => 'Комментарий к XSL-шаблону',
	'xsl_already_exists' => 'XSL-шаблон с таким названием уже существует! Введите уникальное имя XSL-шаблона',
	'main_menu' => 'XSL-шаблон',
	'panel_edit_xsl' => 'Редактировать XSL-шаблон "%s"',
	'panel_edit_xml' => 'XML для XSL-шаблона "%s"',
	'panel_xsl_time' => '%.3f с',
	'panel_xsl_size' => '%s байт',
	'XSL_dir_title' => 'Разделы XSL',
	'XSL_root_dir' => 'XSL-шаблоны',
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
	'option_formatOutput' => 'Форматировать вывод',
	'import' => 'Импорт',
	'import_file' => 'Выберите файл с компьютера',
	'import_button' => 'Загрузить',
	'importXsls_success' => 'Импорт завершен!',
);
